@@ -2,7 +2,7 @@ package Apache::Htpasswd;
 
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION);
 use strict;		# Restrict unsafe variables, references, barewords
-use Carp;
+#use Carp;
 
 @ISA = qw(Exporter);
 
@@ -12,7 +12,7 @@ use Carp;
 
 %EXPORT_TAGS = (all => [@EXPORT_OK]);
 
-$VERSION = '0.9.1';
+$VERSION = '0.9';
 
 sub Version {
 return $VERSION;
